package models

import (
	"github.com/go-ini/ini"
	"os"
)

// ConfigStruct holds the config struct
type ConfigStruct struct {
	Database struct {
		Host     string
		User     string
		Password string
		Database string
	}

	JWTLoginSecret []byte

	FirstUser User `ini:"User"`
}

// Config holds the configuration for the program
var Config = new(ConfigStruct)

// SetConfig initianlises the config and publishes it for other functions to use
func SetConfig() error {

	// File Checks
	if _, err := os.Stat("config.ini"); os.IsNotExist(err) {
		return err
	}

	cfg, err := ini.Load("config.ini")
	if err != nil {
		return err
	}

	err = cfg.MapTo(Config)
	if err != nil {
		return err
	}

	// JWT secret
	Config.JWTLoginSecret = []byte(cfg.Section("General").Key("JWTSecret").String())

	return nil
}
